require 'spec_helper_acceptance'

describe 'sympa' do
  context 'with basic settings' do
    pp = %(
      include sympa
    )

    it 'applies without error' do
      apply_manifest(pp, catch_failures: true)
    end
    it 'applies idempotently' do
      apply_manifest(pp, catch_changes: true)
    end

    srv = [
      'sympa.service',
      'sympa-archive.service',
      'sympa-bounce.service',
      'sympa-outgoing.service',
      'sympa-task.service',
      'wwsympa.socket',
      'wwsympa.service',
    ]

    srv.each do |s|
      describe service(s.to_s) do
        it { is_expected.to be_enabled }
        it { is_expected.to be_running }
      end
    end

    describe file('/home/sympa/etc/sympa_aliases.postfix') do
      it { is_expected.to be_file }
      it { is_expected.to be_owned_by 'sympa' }
      it { is_expected.to be_grouped_into 'sympa' }
      it { is_expected.to be_mode 644 }
    end
  end

  context 'with basic DKIM and DMARC settings enabled' do
    pp = %(
      class { 'sympa':
        dkim_feature     => true,
        dmarc_protection => true,
        dkim_private_key => '-----BEGIN RSA PRIVATE KEY-----
MIIEpQIBAAKCAQEAvcUm36bRVm3hcXoSQr70l6+gTyqGOpCKVJE8xlJoApr85uZP
9tNveGmnnQUoRzMKYZo0Tl26YweY376lPgZ7AQRXDMqyGPMzeKOEIsOF4vVCElva
Lt7hSRYBAoGAVYvoY0gvOQKFNJBHMSEKiC+jt/+1ZNWvHg8Y/XepsIJVf4bBpN18
d9c1L/EPHOm6fmY3PwioRU9V6gnr0zUrtdlvHbWE/2iCRez+QFIf+sCLpXE3K7Xe
20xz5Rs87WC4/QLhQHtP5qTe+reOu8GzUglHo14TMH5KbjmClX0r9sQ=
-----END RSA PRIVATE KEY-----',
      }
    )

    it 'applies without error' do
      apply_manifest(pp, catch_failures: true)
    end
    it 'applies idempotently' do
      apply_manifest(pp, catch_changes: true)
    end

    srv = [
      'sympa.service',
      'sympa-archive.service',
      'sympa-bounce.service',
      'sympa-outgoing.service',
      'sympa-task.service',
      'wwsympa.socket',
      'wwsympa.service',
    ]

    srv.each do |s|
      describe service(s.to_s) do
        it { is_expected.to be_enabled }
        it { is_expected.to be_running }
      end
    end

    describe file('/home/sympa/etc/dkim/listes.example.org/lists-sympa.key') do
      it { is_expected.to be_file }
      it { is_expected.to be_owned_by 'sympa' }
      it { is_expected.to be_grouped_into 'sympa' }
      it { is_expected.to be_mode 600 }
      it { is_expected.to contain('BEGIN RSA PRIVATE KEY') }
    end
  end
end
